@@ -30,14 +30,19 @@
  * In particular it sets a proper role for the rectangle.
  */
 
-#define CLUTTER_DISABLE_DEPRECATION_WARNINGS
-
 #include "cally-rectangle.h"
 #include "cally-actor-private.h"
 
+#define CALLY_RECTANGLE_DEFAULT_DESCRIPTION "A rectangle"
+
+static void cally_rectangle_class_init (CallyRectangleClass *klass);
+static void cally_rectangle_init       (CallyRectangle *rectangle);
+
 /* AtkObject */
 static void                  cally_rectangle_real_initialize (AtkObject *obj,
-                                                              gpointer   data);
+                                                             gpointer   data);
+static const gchar          *cally_rectangle_get_description (AtkObject *obj);
+
 
 G_DEFINE_TYPE (CallyRectangle, cally_rectangle, CALLY_TYPE_ACTOR)
 
@@ -48,6 +53,7 @@ cally_rectangle_class_init (CallyRectangleClass *klass)
   AtkObjectClass *class         = ATK_OBJECT_CLASS (klass);
 
   class->initialize      = cally_rectangle_real_initialize;
+  class->get_description = cally_rectangle_get_description;
 }
 
 static void
@@ -91,3 +97,17 @@ cally_rectangle_real_initialize (AtkObject *obj,
 
   obj->role = ATK_ROLE_IMAGE;
 }
+
+static const gchar *
+cally_rectangle_get_description                    (AtkObject *obj)
+{
+  const gchar *description = NULL;
+
+  g_return_val_if_fail (CALLY_IS_RECTANGLE (obj), NULL);
+
+  description = ATK_OBJECT_CLASS (cally_rectangle_parent_class)->get_description (obj);
+  if (description == NULL)
+    description = CALLY_RECTANGLE_DEFAULT_DESCRIPTION;
+
+  return description;
+}
