@@ -5,9 +5,6 @@
 
 G_BEGIN_DECLS
 
-void            _clutter_event_set_pointer_emulated     (ClutterEvent       *event,
-                                                         gboolean            is_emulated);
-
 /* Reinjecting queued events for processing */
 void            _clutter_process_event                  (ClutterEvent       *event);
 
@@ -19,15 +16,12 @@ void            _clutter_event_set_platform_data        (ClutterEvent       *eve
                                                          gpointer            data);
 gpointer        _clutter_event_get_platform_data        (const ClutterEvent *event);
 
-void            _clutter_event_set_state_full           (ClutterEvent        *event,
-							 ClutterModifierType  button_state,
-							 ClutterModifierType  base_state,
-							 ClutterModifierType  latched_state,
-							 ClutterModifierType  locked_state,
-							 ClutterModifierType  effective_state);
-
 void            _clutter_event_push                     (const ClutterEvent *event,
                                                          gboolean            do_copy);
+void            _clutter_event_set_device               (ClutterEvent       *event,
+                                                         ClutterInputDevice *device);
+void            _clutter_event_set_source_device        (ClutterEvent       *event,
+                                                         ClutterInputDevice *device);
 
 G_END_DECLS
 
