@@ -35,10 +35,7 @@
  * possible to override the drawing pipeline by using small programs
  * also known as "shaders".
  *
- * #ClutterShader is available since Clutter 0.6.
- *
- * #ClutterShader is deprecated since Clutter 1.8; use #ClutterShaderEffect
- * in newly written code.
+ * #ClutterShader is available since Clutter 0.6
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,12 +52,11 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <cogl/cogl.h>
-
-#include "clutter-shader.h"
+#include "cogl/cogl.h"
 
 #include "clutter-debug.h"
 #include "clutter-private.h"
+#include "clutter-shader.h"
 
 /* global list of shaders */
 static GList *clutter_shaders_list = NULL;
@@ -248,8 +244,6 @@ clutter_shader_class_init (ClutterShaderClass *klass)
    * program, if any
    *
    * Since: 0.6
-   *
-   * Deprecated: 1.8: Use #ClutterShaderEffect instead.
    */
   pspec = g_param_spec_string ("vertex-source",
                                P_("Vertex Source"),
@@ -265,8 +259,6 @@ clutter_shader_class_init (ClutterShaderClass *klass)
    * GLSL source code for the fragment shader part of the shader program.
    *
    * Since: 0.6
-   *
-   * Deprecated: 1.8: Use #ClutterShaderEffect instead.
    */
   pspec = g_param_spec_string ("fragment-source",
                                P_("Fragment Source"),
@@ -283,8 +275,6 @@ clutter_shader_class_init (ClutterShaderClass *klass)
    * in the GL context.
    *
    * Since: 0.8
-   *
-   * Deprecated: 1.8: Use #ClutterShaderEffect instead.
    */
   pspec = g_param_spec_boolean ("compiled",
                                 P_("Compiled"),
@@ -300,8 +290,6 @@ clutter_shader_class_init (ClutterShaderClass *klass)
    * Whether the shader is currently used in the GL rendering pipeline.
    *
    * Since: 0.6
-   *
-   * Deprecated: 1.8: Use #ClutterShaderEffect instead.
    */
   pspec = g_param_spec_boolean ("enabled",
                                 P_("Enabled"),
@@ -337,8 +325,6 @@ clutter_shader_init (ClutterShader *self)
  * Return value: a new #ClutterShader.
  *
  * Since: 0.6
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 ClutterShader *
 clutter_shader_new (void)
@@ -381,7 +367,7 @@ clutter_shader_set_source (ClutterShader     *shader,
 
       priv->fragment_source = g_strndup (data, length);
       priv->fragment_is_glsl = is_glsl;
-      g_object_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_FRAGMENT_SOURCE]);
+      _clutter_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_FRAGMENT_SOURCE]);
       break;
 
     case CLUTTER_VERTEX_SHADER:
@@ -389,7 +375,7 @@ clutter_shader_set_source (ClutterShader     *shader,
 
       priv->vertex_source = g_strndup (data, length);
       priv->vertex_is_glsl = is_glsl;
-      g_object_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_VERTEX_SOURCE]);
+      _clutter_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_VERTEX_SOURCE]);
       break;
     }
 
@@ -406,8 +392,6 @@ clutter_shader_set_source (ClutterShader     *shader,
  * program.
  *
  * Since: 0.6
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 void
 clutter_shader_set_fragment_source (ClutterShader      *shader,
@@ -430,8 +414,6 @@ clutter_shader_set_fragment_source (ClutterShader      *shader,
  * program.
  *
  * Since: 0.6
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 void
 clutter_shader_set_vertex_source (ClutterShader      *shader,
@@ -584,8 +566,6 @@ bind_glsl_shader (ClutterShader  *self,
  * Return value: returns TRUE if the shader was succesfully compiled.
  *
  * Since: 0.8
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 gboolean
 clutter_shader_compile (ClutterShader  *shader,
@@ -622,7 +602,7 @@ clutter_shader_compile (ClutterShader  *shader,
     }
 
   priv->compiled = bind_glsl_shader (shader, error);
-  g_object_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_COMPILED]);
+  _clutter_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_COMPILED]);
 
   return priv->compiled;
 }
@@ -634,8 +614,6 @@ clutter_shader_compile (ClutterShader  *shader,
  * Frees up any GL context resources held by the shader.
  *
  * Since: 0.6
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 void
 clutter_shader_release (ClutterShader *shader)
@@ -644,7 +622,7 @@ clutter_shader_release (ClutterShader *shader)
 
   clutter_shader_release_internal (shader);
 
-  g_object_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_COMPILED]);
+  _clutter_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_COMPILED]);
 }
 
 /**
@@ -657,8 +635,6 @@ clutter_shader_release (ClutterShader *shader)
  * Return value: %TRUE if the shader is compiled, linked and ready for use.
  *
  * Since: 0.8
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 gboolean
 clutter_shader_is_compiled (ClutterShader *shader)
@@ -680,8 +656,6 @@ clutter_shader_is_compiled (ClutterShader *shader)
  * used instead.
  *
  * Since: 0.6
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 void
 clutter_shader_set_is_enabled (ClutterShader *shader,
@@ -716,7 +690,7 @@ clutter_shader_set_is_enabled (ClutterShader *shader,
       else
         cogl_program_use (COGL_INVALID_HANDLE);
 
-      g_object_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_ENABLED]);
+      _clutter_notify_by_pspec (G_OBJECT (shader), obj_props[PROP_ENABLED]);
     }
 }
 
@@ -729,8 +703,6 @@ clutter_shader_set_is_enabled (ClutterShader *shader,
  * Return value: %TRUE if the shader is enabled.
  *
  * Since: 0.6
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 gboolean
 clutter_shader_get_is_enabled (ClutterShader *shader)
@@ -751,8 +723,6 @@ clutter_shader_get_is_enabled (ClutterShader *shader)
  * a #ClutterShader.
  *
  * Since: 1.0
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 void
 clutter_shader_set_uniform (ClutterShader *shader,
@@ -844,8 +814,6 @@ _clutter_shader_release_all (void)
  * shader object and should never be modified or freed
  *
  * Since: 0.6
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 const gchar *
 clutter_shader_get_fragment_source (ClutterShader *shader)
@@ -866,8 +834,6 @@ clutter_shader_get_fragment_source (ClutterShader *shader)
  * shader object and should never be modified or freed
  *
  * Since: 0.6
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 const gchar *
 clutter_shader_get_vertex_source (ClutterShader *shader)
@@ -888,8 +854,6 @@ clutter_shader_get_vertex_source (ClutterShader *shader)
  *   not be unreferenced
  *
  * Since: 1.0
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 CoglHandle
 clutter_shader_get_cogl_program (ClutterShader *shader)
@@ -910,8 +874,6 @@ clutter_shader_get_cogl_program (ClutterShader *shader)
  *   and it should not be unreferenced
  *
  * Since: 1.0
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 CoglHandle
 clutter_shader_get_cogl_fragment_shader (ClutterShader *shader)
@@ -932,8 +894,6 @@ clutter_shader_get_cogl_fragment_shader (ClutterShader *shader)
  *   and it should not be unreferenced
  *
  * Since: 1.0
- *
- * Deprecated: 1.8: Use #ClutterShaderEffect instead.
  */
 CoglHandle
 clutter_shader_get_cogl_vertex_shader (ClutterShader *shader)
